"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registrationReducer = void 0;
var _TransitState = require("../TransitState");
/**
 * @packageDocumentation
 * @module RegistrationUIContext
 */

/**
 * Default reducer for global [[RegistrationUIState]].
 *
 * @param prevState Previous [[RegistrationUIState]] to update.
 * @param action State change action, which should be of type [[RegistrationActions]].
 */
const registrationReducer = (prevState, action) => {
  switch (action.type) {
    case 'Registration/RegisterUser/Reset':
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          registrationTransit: _TransitState.initialTransitState,
          email: null,
          organizationName: null
        }
      };
    case 'Registration/RegisterUser/Started':
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          registrationTransit: (0, _TransitState.transitStart)(action.payload.transitId)
        }
      };
    case 'Registration/RegisterUser/Succeeded':
      if (prevState.inviteRegistration.registrationTransit.transitId !== action.payload.transitId) {
        return prevState;
      }
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          registrationTransit: (0, _TransitState.transitSuccess)(action.payload.transitId),
          email: action.payload.email,
          organizationName: action.payload.organizationName
        }
      };
    case 'Registration/RegisterUser/Failed':
      if (prevState.inviteRegistration.registrationTransit.transitId !== action.payload.transitId) {
        return prevState;
      }
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          registrationTransit: (0, _TransitState.transitFailed)(action.payload.errorMessage, action.payload.transitId),
          email: null,
          organizationName: null
        }
      };
    case 'Registration/LoadEula/Reset':
      return {
        ...prevState,
        eulaTransit: _TransitState.initialTransitState
      };
    case 'Registration/LoadEula/Started':
      return {
        ...prevState,
        eulaTransit: (0, _TransitState.transitStart)(action.payload.transitId)
      };
    case 'Registration/LoadEula/Succeeded':
      if (prevState.eulaTransit.transitId !== action.payload.transitId) {
        return prevState;
      }
      return {
        ...prevState,
        eulaTransit: (0, _TransitState.transitSuccess)(action.payload.transitId)
      };
    case 'Registration/LoadEula/Failed':
      if (prevState.eulaTransit.transitId !== action.payload.transitId) {
        return prevState;
      }
      return {
        ...prevState,
        eulaTransit: (0, _TransitState.transitFailed)(action.payload.errorMessage, action.payload.transitId)
      };
    case 'Registration/ValidateUser/Reset':
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          validationTransit: _TransitState.initialTransitState
        }
      };
    case 'Registration/ValidateUser/Started':
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          validationTransit: (0, _TransitState.transitStart)(action.payload.transitId)
        }
      };
    case 'Registration/ValidateUser/Succeeded':
      if (prevState.inviteRegistration.validationTransit.transitId !== action.payload.transitId) {
        return prevState;
      }
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          validationTransit: (0, _TransitState.transitSuccess)(action.payload.transitId)
        }
      };
    case 'Registration/ValidateUser/Failed':
      if (prevState.inviteRegistration.validationTransit.transitId !== action.payload.transitId) {
        return prevState;
      }
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          validationTransit: (0, _TransitState.transitFailed)(action.payload.errorMessage, action.payload.transitId)
        }
      };
    case 'Registration/RequestCode/Reset':
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          codeRequestTransit: _TransitState.initialTransitState
        }
      };
    case 'Registration/RequestCode/Started':
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          codeRequestTransit: (0, _TransitState.transitStart)(action.payload.transitId)
        }
      };
    case 'Registration/RequestCode/Succeeded':
      if (prevState.inviteRegistration.codeRequestTransit.transitId !== action.payload.transitId) {
        return prevState;
      }
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          codeRequestTransit: (0, _TransitState.transitSuccess)(action.payload.transitId)
        }
      };
    case 'Registration/RequestCode/Failed':
      if (prevState.inviteRegistration.codeRequestTransit.transitId !== action.payload.transitId) {
        return prevState;
      }
      return {
        ...prevState,
        inviteRegistration: {
          ...prevState.inviteRegistration,
          codeRequestTransit: (0, _TransitState.transitFailed)(action.payload.errorMessage, action.payload.transitId)
        }
      };
    default:
      return prevState;
  }
};
exports.registrationReducer = registrationReducer;
//# sourceMappingURL=reducer.js.map